@@ -73,6 +73,70 @@ Bayonne::statetab Bayonne::states[] = {
 	{"final", &BayonneSession::stateFinal, ' '},
 	{NULL, NULL, ' '}};
 
+bool Bayonne::loadPlugin(const char *prefix, const char *path)
+{
+        char pathbuf[256];
+        const char *cp, *kv;
+        DSO *dso;
+
+#ifdef	WIN32
+	if(!prefix)
+		"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins"
+#else
+	if(!prefix)
+		prefix = LIBDIR_FILES;
+#endif
+
+        cp = strrchr(path, '/');
+        if(!cp)
+                cp = strrchr(path, '\\');
+        if(!cp)
+                cp = strrchr(path, ':');
+        if(!cp)
+        {
+#ifdef  WIN32
+                snprintf(pathbuf, sizeof(pathbuf),
+                        "%s/%s." RLL_SUFFIX, prefix, path);
+#else
+                if(!strnicmp(prefix, "..", 2))
+                        snprintf(pathbuf, sizeof(pathbuf),
+                        "%s/%s/.libs/%s.dso", prefix, path, path);
+                else
+                        snprintf(pathbuf, sizeof(pathbuf),
+                                "%s/%s.dso", prefix, path);
+#endif  
+                cp = path;
+                path = pathbuf;
+        }
+        else
+                ++cp;
+
+        kv = server->getLast(path);
+        if(kv)
+        {
+                if(!stricmp(kv, "loaded"))
+                        return true;
+		return false;
+	}
+
+        if(!canAccess(path))
+        {
+                server->errlog("access", path);
+                return false;
+        }
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+                kv = dso->getError();
+                server->setValue(path, kv);
+                server->errlog("error", kv);
+                return false;
+        }
+        server->setValue(path, "loaded");
+        return true;                
+}
+
 Bayonne::Handler Bayonne::getState(const char *id)
 {
 	unsigned pos = 0;
