@@ -750,6 +750,15 @@ public:
 	 * @param script image from useImage.
 	 */
 	static void endImage(ScriptImage *img);
+
+	/**
+	 * Load a plugin module.
+	 *
+	 * @param prefix path for plugin.
+	 * @param id of plugin.
+	 * @return true if successful.
+	 */
+	static bool loadPlugin(const char *prefix, const char *path);
 };
 
 /**
@@ -791,7 +800,7 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static bool load(const char *name);
+	static bool load(const char *prefix, const char *name);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
@@ -1158,6 +1167,14 @@ public:
 	 */
 	static BayonneDriver *get(const char *id);
 
+	/**
+	 * Load a bayonne driver into memory.
+	 *
+	 * @param driver name to load.
+	 * @return NULL or pointer to loaded driver.
+	 */
+	static BayonneDriver *load(const char *prefix, const char *id);
+
 	/**
 	 * Get list of driver names into string array.
 	 *
