@@ -237,7 +237,7 @@ const char *Checks::chkLoad(Line *line, ScriptImage *img)
 	while(count < line->argc)
 	{
 		cp = line->args[count++];
-		loadModule(cp);
+		loadPlugin(keypaths.getLast("modules"), cp);
 	}
 	BayonneService::start();
 	
