@@ -58,12 +58,14 @@ using namespace std;
 #define	RUN_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Logs"
 #define	LIBEXEC_FILES	"C:\\Program Files\\GNU Telephony\\Bayonne\\Libexec"
 #define	LIBDIR_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Runtime"
-#define	MODULE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Modules"
+#define	MODULE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Plugins"
 #define	DRIVER_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Drivers"
+#define	PHRASE_FILES	"C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Languages"
 
 #else
 #define	MODULE_FILES	LIBDIR_FILES
 #define	DRIVER_FILES	LIBDIR_FILES
+#define	PHRASE_FILES	LIBDIR_FILES
 #endif
 
 static Keydata::Define paths[] = {
@@ -74,6 +76,7 @@ static Keydata::Define paths[] = {
 	{"config", CONFIG_FILES},
 	{"modules", MODULE_FILES},
 	{"drivers", DRIVER_FILES},
+	{"phrases", PHRASE_FILES},
 	{"scripts", SCRIPT_FILES},
 	{"prompts", PROMPT_FILES},
 	{NULL, NULL}};
@@ -310,6 +313,7 @@ static void commonConfig(void)
 void testConfig(char *argv0)
 {
 #ifdef	WIN32
+	keypaths.setValue("phrases", "Debug");
 	keypaths.setValue("drivers", "Debug");
 	keypaths.setValue("modules", "Debug");
 	keypaths.setValue("prompts", "../audio");
@@ -333,6 +337,7 @@ void testConfig(char *argv0)
 	keypaths.setValue("libexec", pbuf);
 	keypaths.setValue("modules", "../modules");
 	keypaths.setValue("drivers", "../modules");
+	keypaths.setValue("phrases", "../modules/languages/.libs");
 	keypaths.setValue("prompts", SOURCE_FILES "/audio");
 	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
 	keypaths.setValue("config", SOURCE_FILES "/config");
@@ -765,70 +770,4 @@ void purgedir(const char *dir)
 	}
 }
 
-bool loadModule(const char *path, bool stack)
-{
-	const char *prefix = keypaths.getLast("modules");
-	char pathbuf[256];
-	const char *cp, *kv;
-	DSO *dso;
-	char *suffix = "dso";
-
-	if(stack)
-	{
-		prefix = keypaths.getLast("drivers");
-		suffix = "ivr";
-	}
-
-	cp = strrchr(path, '/');
-	if(!cp)
-		cp = strrchr(path, '\\');
-	if(!cp)
-		cp = strrchr(path, ':');
-	if(!cp)
-	{
-#ifdef  WIN32
-        	snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
-#else
-		if(!strnicmp(prefix, "..", 2))
-			snprintf(pathbuf, sizeof(pathbuf), 
-				"%s/%s/.libs/%s.%s", prefix, path, path, suffix);
-		else
-			snprintf(pathbuf, sizeof(pathbuf), 
-				"%s/%s.%s", prefix, path, suffix);
-#endif	
-		cp = path;
-		path = pathbuf;
-	}
-	else
-		++cp;
-
-	kv = keyoptions.getLast(path);
-	if(kv)
-	{
-		if(!stricmp(kv, "loaded"))
-			return true;
-
-		errlog("%s: %s\n", cp, kv); 	
-		return false;
-	}		
-
-	if(!canAccess(path))
-	{
-		errlog("access", "%s: unable to load", path);
-		return false;
-	}
-
-	errlog("debug", "server loading %s", cp);
-	dso = new DSO(path);
-	if(!dso->isValid())
-	{
-		kv = dso->getError();
-		keyoptions.setValue(path, kv);
-		errlog("error", "%s: %s", cp, kv);
-		return false;
-	}
-	keyoptions.setValue(path, "loaded");
-	return true;
-}
-
 } // namespace
