@@ -647,7 +647,7 @@ bool Runtime::command(char *cmd)
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
 		if(!cmd)
 			return false;
-		rtn = loadModule(cmd);
+		rtn = Bayonne::loadPlugin(keypaths.getLast("modules"), cmd);
 		if(rtn)
 			BayonneService::start();
 		return rtn;
