@@ -87,18 +87,13 @@ static void version(void)
 
 static void loadStack(const char *id)
 {
-	BayonneDriver *d;
+	BayonneDriver *d = BayonneDriver::load(keypaths.getLast("drivers"), id);
 
-	if(!loadModule(id, true))
+	if(!d)
 	{
-failed:
 		cerr << "bayonne cannot load " << id << " stack" << endl;
 		stop(-1);
 	}
-	d = BayonneDriver::get(id);
-	if(!d)
-		goto failed;
-
 	d->start();
 }	
 
@@ -114,7 +109,8 @@ static void loading(void)
 	Libexec::allocate();
 #endif
 
-	if(!loadModule(keyoptions.getLast("driver")))
+	driver = BayonneDriver::load(keypaths.getLast("drivers"), dname);
+	if(!driver)
 		stop(-1);
 
 	if(!count)
@@ -123,10 +119,9 @@ static void loading(void)
 	keys = (char **)keyoptions.getList("modules");
 
 	while(*keys)
-		loadModule(*keys++);
+		Bayonne::loadPlugin(keypaths.getLast("modules"), *keys++);
 
 start:
-	driver = BayonneDriver::get(dname);
 	if(!driver)
 		stop(-1);
 
